=============
Release notes
=============

This page links to the release notes for Salt, including the current, upcoming,
and past releases.

* New releases and security updates are announced on the
  `Salt Project blog <https://saltproject.io/blog/>`_. You can subscribe to an
  `RSS feed <https://saltproject.io/rss-feeds/>`_ for announcements.
* See the :ref:`version numbers<version-numbers>` page for more information
  about the version numbering scheme.


Upcoming release
================

.. releasestree::
    :maxdepth: 1
    :glob:

    3006.*

See `Install a release candidate <https://docs.saltproject.io/salt/install-guide/en/latest/topics/release-candidate.html>`_
for more information about installing an RC when one is available.

Previous releases
=================

.. releasestree::
    :maxdepth: 1
    :glob:

    3005*
    3004*
    3003*
    3002*
    3001*
    3000*
    2019.2.*
    2018.3.*
    2017.7.*
    2016.11.*
    2016.3.*
    2015.8.*
    2015.5.*
    2014.7.*
    2014.1.*
    0.*


.. seealso:: :ref:`Legacy salt-cloud release docs <legacy-salt-cloud-release-notes>`

.. seealso:: :ref:`Legacy salt-api release docs <legacy-salt-api-release-notes>`
